#############################################################################
# The finance package is open source under the `Python Software Foundation  #
# License <http://www.opensource.org/licenses/PythonSoftFoundation.php>`_   #
#############################################################################

'''
**********************
Mathematical meta code
**********************



Class definitions and documentation
===================================

'''

__version__ = '0.1'

from algebraic_structures import CummutativeAddition, \
                                 CummutativeMultiplication, Power

__all__ = [
    'CummutativeAddition',
    'CummutativeMultiplication',
    'Power'
]